Changelog
=========

:Version: 1.0.0 of 2017-09-29

Some minor documentation and metadata changes. This version is included with 
Patzelt and Bouchaud (JSTAT 2017) as an online supplement.


:Version: 1.0-rc.1 of 2017-09-28

Refactoring for public release in pip-installable form.


:Version: [unreleased] of 2017-01-16

Begin of initial development for research.